# Best Practices for describing tabular data transformations

Many data science and machine learning projects work with tabular data. Popular ways of describing transformations
of such tabular data with python are using pandas, polars, or SQL. This section provides best practices for working
with tabular data in python.

* [beware the flatfile & embrace working with entities](/examples/best_practices_entities)
* [start sql, finish polars](/examples/best_practices_sql_polars)

```{toctree}
/examples/best_practices_entities
/examples/best_practices_sql_polars
```
